<?php
if (!defined('ABSPATH')) {
    exit;
}

add_action('rest_api_init', function () {
    
    add_filter('rest_pre_serve_request', function ($served, $result) {
        header('Access-Control-Allow-Origin: *');
        header('Access-Control-Allow-Methods: GET, POST, OPTIONS');
        header('Access-Control-Allow-Headers: Content-Type, X-Requested-With');
        header('Access-Control-Allow-Credentials: true');
        header('Access-Control-Expose-Headers: X-WP-Total, X-WP-TotalPages');
        return $served;
    }, 10, 2);
});

add_action('rest_api_init', function () {
    register_rest_route('api-post-grid/v1', '/posts', [
        'methods' => WP_REST_Server::READABLE,
        'callback' => 'api_post_grid_get_posts',
        'args' => [
            'post_type' => [
                'required' => false,
                'default' => 'post',
            ],
            'term_id' => [
                'required' => false,
                'validate_callback' => function ($param) {
                    return is_numeric($param) || empty($param);
                }
            ],
            'taxonomy' => [
                'required' => false,
            ],
            'category' => [
                'required' => false,
                'validate_callback' => function ($param) {
                    return is_numeric($param) || empty($param);
                }
            ],
            'per_page' => [
                'required' => false,
                'default' => 12,
                'validate_callback' => function ($param) {
                    return is_numeric($param) && $param > 0;
                }
            ],
            'page' => [
                'required' => false,
                'default' => 1,
                'validate_callback' => function ($param) {
                    return is_numeric($param) && $param > 0;
                }
            ],
            'order' => [
                'required' => false,
                'default' => 'DESC',
                'validate_callback' => function ($param) {
                    return in_array(strtoupper($param), ['ASC', 'DESC']);
                }
            ],
            'orderby' => [
                'required' => false,
                'default' => 'date'
            ],
            'status' => [
                'required' => false,
                'default' => 'publish'
            ]
        ],
        'permission_callback' => '__return_true'
    ]);

    register_rest_route('api-post-grid/v1', '/post-types', [
        'methods' => 'GET',
        'callback' => 'api_post_grid_get_post_types',
        'permission_callback' => '__return_true'
    ]);

    register_rest_route('api-post-grid/v1', '/taxonomies/(?P<post_type>[a-zA-Z0-9-_]+)', [
        'methods' => 'GET',
        'callback' => 'api_post_grid_get_taxonomies',
        'permission_callback' => '__return_true'
    ]);

    register_rest_route('api-post-grid/v1', '/terms/(?P<taxonomy>[a-zA-Z0-9-_]+)', [
        'methods' => 'GET',
        'callback' => 'api_post_grid_get_terms',
        'permission_callback' => '__return_true'
    ]);
});
